from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.Graphics.Canvas
import win32more.Microsoft.Graphics.Canvas.UI.Composition
import win32more.Microsoft.UI.Composition
import win32more.Windows.Foundation
class CanvasComposition(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Graphics.Canvas.UI.Composition.CanvasComposition'
    @winrt_classmethod
    def CreateCompositionGraphicsDevice(cls: win32more.Microsoft.Graphics.Canvas.UI.Composition.ICanvasCompositionStatics, compositor: win32more.Microsoft.UI.Composition.Compositor, canvasDevice: win32more.Microsoft.Graphics.Canvas.CanvasDevice) -> win32more.Microsoft.UI.Composition.CompositionGraphicsDevice: ...
    @winrt_classmethod
    def GetCanvasDevice(cls: win32more.Microsoft.Graphics.Canvas.UI.Composition.ICanvasCompositionStatics, graphicsDevice: win32more.Microsoft.UI.Composition.CompositionGraphicsDevice) -> win32more.Microsoft.Graphics.Canvas.CanvasDevice: ...
    @winrt_classmethod
    def SetCanvasDevice(cls: win32more.Microsoft.Graphics.Canvas.UI.Composition.ICanvasCompositionStatics, graphicsDevice: win32more.Microsoft.UI.Composition.CompositionGraphicsDevice, canvasDevice: win32more.Microsoft.Graphics.Canvas.CanvasDevice) -> Void: ...
    @winrt_classmethod
    def CreateDrawingSession(cls: win32more.Microsoft.Graphics.Canvas.UI.Composition.ICanvasCompositionStatics, drawingSurface: win32more.Microsoft.UI.Composition.CompositionDrawingSurface) -> win32more.Microsoft.Graphics.Canvas.CanvasDrawingSession: ...
    @winrt_classmethod
    def CreateDrawingSessionWithUpdateRect(cls: win32more.Microsoft.Graphics.Canvas.UI.Composition.ICanvasCompositionStatics, drawingSurface: win32more.Microsoft.UI.Composition.CompositionDrawingSurface, updateRect: win32more.Windows.Foundation.Rect) -> win32more.Microsoft.Graphics.Canvas.CanvasDrawingSession: ...
    @winrt_classmethod
    def CreateDrawingSessionWithUpdateRectAndDpi(cls: win32more.Microsoft.Graphics.Canvas.UI.Composition.ICanvasCompositionStatics, drawingSurface: win32more.Microsoft.UI.Composition.CompositionDrawingSurface, updateRectInPixels: win32more.Windows.Foundation.Rect, dpi: Single) -> win32more.Microsoft.Graphics.Canvas.CanvasDrawingSession: ...
    @winrt_classmethod
    def Resize(cls: win32more.Microsoft.Graphics.Canvas.UI.Composition.ICanvasCompositionStatics, drawingSurface: win32more.Microsoft.UI.Composition.CompositionDrawingSurface, sizeInPixels: win32more.Windows.Foundation.Size) -> Void: ...
class ICanvasCompositionStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Graphics.Canvas.UI.Composition.ICanvasCompositionStatics'
    _iid_ = Guid('{162deb43-1cf5-46f8-a0af-356b23158f92}')
    @winrt_commethod(6)
    def CreateCompositionGraphicsDevice(self, compositor: win32more.Microsoft.UI.Composition.Compositor, canvasDevice: win32more.Microsoft.Graphics.Canvas.CanvasDevice) -> win32more.Microsoft.UI.Composition.CompositionGraphicsDevice: ...
    @winrt_commethod(7)
    def GetCanvasDevice(self, graphicsDevice: win32more.Microsoft.UI.Composition.CompositionGraphicsDevice) -> win32more.Microsoft.Graphics.Canvas.CanvasDevice: ...
    @winrt_commethod(8)
    def SetCanvasDevice(self, graphicsDevice: win32more.Microsoft.UI.Composition.CompositionGraphicsDevice, canvasDevice: win32more.Microsoft.Graphics.Canvas.CanvasDevice) -> Void: ...
    @winrt_commethod(9)
    def CreateDrawingSession(self, drawingSurface: win32more.Microsoft.UI.Composition.CompositionDrawingSurface) -> win32more.Microsoft.Graphics.Canvas.CanvasDrawingSession: ...
    @winrt_commethod(10)
    def CreateDrawingSessionWithUpdateRect(self, drawingSurface: win32more.Microsoft.UI.Composition.CompositionDrawingSurface, updateRect: win32more.Windows.Foundation.Rect) -> win32more.Microsoft.Graphics.Canvas.CanvasDrawingSession: ...
    @winrt_commethod(11)
    def CreateDrawingSessionWithUpdateRectAndDpi(self, drawingSurface: win32more.Microsoft.UI.Composition.CompositionDrawingSurface, updateRectInPixels: win32more.Windows.Foundation.Rect, dpi: Single) -> win32more.Microsoft.Graphics.Canvas.CanvasDrawingSession: ...
    @winrt_commethod(12)
    def Resize(self, drawingSurface: win32more.Microsoft.UI.Composition.CompositionDrawingSurface, sizeInPixels: win32more.Windows.Foundation.Size) -> Void: ...


make_ready(__name__)
